==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1RBDPersistentVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1RBDPersistentVolumeSourceFluent<A extends V1RBDPersistentVolumeSourceFluent<A>> extends Fluent<A>{


    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public String getImage();
    public A withImage(String image);
    public Boolean hasImage();
    public String getKeyring();
    public A withKeyring(String keyring);
    public Boolean hasKeyring();
    public A addToMonitors(int index,String item);
    public A setToMonitors(int index,String item);
    public A addToMonitors(String... items);
    public A addAllToMonitors(Collection<String> items);
    public A removeFromMonitors(String... items);
    public A removeAllFromMonitors(Collection<String> items);
    public List<String> getMonitors();
    public String getMonitor(int index);
    public String getFirstMonitor();
    public String getLastMonitor();
    public String getMatchingMonitor(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withMonitors(List<String> monitors);
    public A withMonitors(String... monitors);
    public Boolean hasMonitors();
    public String getPool();
    public A withPool(String pool);
    public Boolean hasPool();
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(boolean arg1);
    public A withNewReadOnly(String arg1);
    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1SecretReference getSecretRef();
    public V1SecretReference buildSecretRef();
    public A withSecretRef(V1SecretReference secretRef);
    public Boolean hasSecretRef();
    public V1RBDPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
    public V1RBDPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(V1SecretReference item);
    public V1RBDPersistentVolumeSourceFluent.SecretRefNested<A> editSecretRef();
    public V1RBDPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public V1RBDPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(V1SecretReference item);
    public String getUser();
    public A withUser(String user);
    public Boolean hasUser();

    public interface SecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1SecretReferenceFluent<V1RBDPersistentVolumeSourceFluent.SecretRefNested<N>>{

        
    public N and();    public N endSecretRef();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1RBDPersistentVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1RBDPersistentVolumeSourceFluent<A extends V1RBDPersistentVolumeSourceFluent<A>> extends Fluent<A>{


    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A withNewFsType(String arg1);
    public A withNewFsType(StringBuilder arg1);
    public A withNewFsType(StringBuffer arg1);
    public String getImage();
    public A withImage(String image);
    public Boolean hasImage();
    public A withNewImage(String arg1);
    public A withNewImage(StringBuilder arg1);
    public A withNewImage(StringBuffer arg1);
    public String getKeyring();
    public A withKeyring(String keyring);
    public Boolean hasKeyring();
    public A withNewKeyring(String arg1);
    public A withNewKeyring(StringBuilder arg1);
    public A withNewKeyring(StringBuffer arg1);
    public A addToMonitors(int index,String item);
    public A setToMonitors(int index,String item);
    public A addToMonitors(String... items);
    public A addAllToMonitors(Collection<String> items);
    public A removeFromMonitors(String... items);
    public A removeAllFromMonitors(Collection<String> items);
    public List<String> getMonitors();
    public String getMonitor(int index);
    public String getFirstMonitor();
    public String getLastMonitor();
    public String getMatchingMonitor(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingMonitor(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withMonitors(List<String> monitors);
    public A withMonitors(String... monitors);
    public Boolean hasMonitors();
    public A addNewMonitor(String arg1);
    public A addNewMonitor(StringBuilder arg1);
    public A addNewMonitor(StringBuffer arg1);
    public String getPool();
    public A withPool(String pool);
    public Boolean hasPool();
    public A withNewPool(String arg1);
    public A withNewPool(StringBuilder arg1);
    public A withNewPool(StringBuffer arg1);
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1SecretReference getSecretRef();
    public V1SecretReference buildSecretRef();
    public A withSecretRef(V1SecretReference secretRef);
    public Boolean hasSecretRef();
    public V1RBDPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
    public V1RBDPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(V1SecretReference item);
    public V1RBDPersistentVolumeSourceFluent.SecretRefNested<A> editSecretRef();
    public V1RBDPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public V1RBDPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(V1SecretReference item);
    public String getUser();
    public A withUser(String user);
    public Boolean hasUser();
    public A withNewUser(String arg1);
    public A withNewUser(StringBuilder arg1);
    public A withNewUser(StringBuffer arg1);

    public interface SecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1SecretReferenceFluent<V1RBDPersistentVolumeSourceFluent.SecretRefNested<N>>{

        
    public N and();    public N endSecretRef();
}


}
